Parallel Solution Transfer Service with DTK2 and MOAB
=====================================================

.. image:: https://travis-ci.org/chiao45/parpydtk2.svg?branch=parallel
    :target: https://travis-ci.org/chiao45/parpydtk2
.. image:: https://img.shields.io/pypi/v/parpydtk2.svg?branch=parallel
    :target: https://pypi.org/project/parpydtk2/
.. image:: https://img.shields.io/pypi/l/parpydtk2.svg?branch=parallel
    :target: https://pypi.org/project/parpydtk2/

This package provides a Python3 interface of using
`DTK2 <http://ornl-cees.github.io/DataTransferKit/>`_ and
`MOAB <http://sigma.mcs.anl.gov/moab-library/>`_ in parallel with MPI for
multi-physics coupling problems.

Documentation
-------------

.. image:: https://img.shields.io/badge/doc-ready-blue.svg
    :target: https://chiao45.github.io/parpydtk2-doc/

Installation
------------

.. image:: https://img.shields.io/badge/install-ready-yellow.svg
    :target: https://chiao45.github.io/parpydtk2-doc/install.html

License
-------

MIT License

Copyright (c) 2018 Qiao Chen
